--  ----------------------------------------------------------------------------
-- FILENAME:      netiq_risk_mysql_install.sql                                --
-- VERSION:       1                                                           --
-- DATABASE:      MySQL 5.0.20 or later                                       --
-- SUMMARY:       Creates database objects necessary for NAM Risk Management. --
-- INSTRUCTIONS:  Execute as user 'root' or some user with superuser          --
--                privileges from the command line client                     --
--                (e.g., mysql> \. netiq_risk_mysql_install.sql)              --
--                or copy this content and paste in the MySQL QueryBrowser.   --
-- DISPLAY:       monospaced font, 80 columns                                 --
--  ----------------------------------------------------------------------------


-- GENERAL NOTES:
-- MySQL statements are sensitive to comments inside of SQL statements.

--  ----------------------------------------------------------------------------
-- CREATE DATABASE             		                                      --
--  ----------------------------------------------------------------------------

DELIMITER ;
USE mysql;

-- In MySQL, create the NAM database for RISK Management.
CREATE DATABASE IF NOT EXISTS netiq_risk;

--  ----------------------------------------------------------------------------
--      CREATE TABLES                                                         --
--                                                                            --
--  ----------------------------------------------------------------------------


CREATE TABLE IF NOT EXISTS netiq_risk.usr
(
  id         NATIONAL VARCHAR(100)  NOT NULL,
  uname       NATIONAL VARCHAR(100),
  dn       NATIONAL VARCHAR(500),
  
  PRIMARY KEY (id),
  INDEX idx_usr_name (uname)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.region
(
  rid         BIGINT                 AUTO_INCREMENT  NOT NULL,
  rname       NATIONAL VARCHAR(100),
  rcode  NATIONAL VARCHAR(32),
  
  PRIMARY KEY (rid),
  INDEX idx_region_rname (rname)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.geo
(
  gid         BIGINT                 AUTO_INCREMENT  NOT NULL,
  gname       NATIONAL VARCHAR(100),
  rid         BIGINT,
  
  PRIMARY KEY (gid),
  INDEX idx_geo_gname (gname),
  INDEX idx_geo_rid (rid),
   CONSTRAINT FOREIGN KEY fk_geo_rid (rid) REFERENCES netiq_risk.region(rid)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.country
(
  cid         BIGINT                 AUTO_INCREMENT  NOT NULL,
  cname       NATIONAL VARCHAR(100),
  rid         BIGINT,
  ccode  NATIONAL VARCHAR(32),
  
  PRIMARY KEY (cid),
  INDEX idx_country_cname (cname),
  INDEX idx_country_rid (rid),
   CONSTRAINT FOREIGN KEY fk_country_rid (rid) REFERENCES netiq_risk.region(rid)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.state
(
  sid         BIGINT                 AUTO_INCREMENT  NOT NULL,
  sname       NATIONAL VARCHAR(100),
  scode       NATIONAL VARCHAR(32),
  cid         BIGINT,
  
  PRIMARY KEY (sid),
  CONSTRAINT FOREIGN KEY fk_state_sid (sid) REFERENCES netiq_risk.country(cid)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.city
(
  citid         BIGINT                 AUTO_INCREMENT  NOT NULL,
  citname       NATIONAL VARCHAR(100),
  cid         BIGINT,
  
  PRIMARY KEY (citid),
  INDEX idx_city_citname (citname),
  INDEX idx_city_cid (cid),
   CONSTRAINT FOREIGN KEY fk_city_cid (cid) REFERENCES netiq_risk.country(cid)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.transaction
(
  uuid         BIGINT                 AUTO_INCREMENT  NOT NULL,
  id           NATIONAL VARCHAR(100)  NOT NULL,
  displayname NATIONAL VARCHAR(32),
  riskscore BIGINT,
  lastlogintime BIGINT,
  city      BIGINT,
  country   BIGINT,
  geolocation BIGINT,
  state  BIGINT,
  region BIGINT,
  ip VARCHAR(40),
  loginresult       CHAR(1)      DEFAULT 'F' NOT NULL,
  riskcategory VARCHAR(10),
  createddate TIMESTAMP,
  createdby NATIONAL VARCHAR(32),
  modifiedby NATIONAL VARCHAR(32),
  modifieddate TIMESTAMP,
  twofactorauthresult CHAR(1)      DEFAULT 'F' NOT NULL,
  postcode NATIONAL VARCHAR(32),
  regioncode NATIONAL VARCHAR(32),
  metrocode NATIONAL VARCHAR(32),
  areacode NATIONAL VARCHAR(32),
  deviceid NATIONAL VARCHAR(32),
  errormsg NATIONAL VARCHAR(200),
  timeZone NATIONAL VARCHAR(50),
  organization NATIONAL VARCHAR(100),
  anonymous  CHAR(1), 
  privateipaddress  CHAR(1), 

  PRIMARY KEY (uuid),
  INDEX idx_transaction_id (id),
  INDEX idx_transaction_match_ip (id, ip),
  INDEX idx_transaction_match_city (id, city),
  INDEX idx_transaction_match_country (id, country),
  INDEX idx_transaction_match_state (id, state),
  INDEX idx_transaction_match_region (id, region),
   CONSTRAINT FOREIGN KEY fk_transction_id (id) REFERENCES netiq_risk.usr(id)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.extra
(
  id         NATIONAL VARCHAR(100)  NOT NULL,
  custom_string_entry1       NATIONAL VARCHAR(100),
  custom_int_entry2       BIGINT,
  custom_char_entry3       CHAR(1),
  custom_boolean_entry4      BOOLEAN,
  
  CONSTRAINT FOREIGN KEY fk_extra_id (id) REFERENCES netiq_risk.usr(id)
)
ENGINE=INNODB;

CREATE TABLE IF NOT EXISTS netiq_risk.version
(
  prodname       NATIONAL VARCHAR(100),
  prodver       NATIONAL VARCHAR(100),
   INDEX idx_version_prodname (prodname)
)
ENGINE=INNODB;

--  ----------------------------------------------------------------------------
--      GRAND ALL Permissions                                                 --
--                                                                            --
--  ----------------------------------------------------------------------------
GRANT ALL PRIVILEGES ON netiq_risk.* TO 'root'@'%' IDENTIFIED BY 'novell' WITH GRANT OPTION;
FLUSH PRIVILEGES;

--  ----------------------------------------------------------------------------
--      prepopulate static data                                               --
--                                                                            --
--  ----------------------------------------------------------------------------

insert into netiq_risk.region(rname) values ('Unknown');
insert into netiq_risk.geo(gname,rid) values ('Unknown',1);
insert into netiq_risk.country(cname,rid) values ('Unknown',1);
insert into netiq_risk.state(sname,cid) values ('Unknown',1);
insert into netiq_risk.city(citname,cid) values ('Unknown',1);
commit;

